// Copyright (c) 2024 Dominic Masters
// 
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

#pragma once
#include "dawn.hpp"
#include "display/RenderManager.hpp"

namespace Dawn {
  class Scene;

  class Game : std::enable_shared_from_this<Game> {
    private:
      std::shared_ptr<Scene> currentScene;

    public:
      RenderManager renderManager;

      /**
       * Constructs a new instance of Game, the class majorily responsible for
       * handling all internal dawn functions outside of platform-centric things
       * like windowing and graphics.
       */
      Game();

      /**
       * Gets the current scene.
       * 
       * @return The current scene.
       */
      std::shared_ptr<Scene> getCurrentScene();

      /**
       * Sets the current scene to the provided scene.
       * 
       * @param scene The scene to set as the current scene.
       */
      void setCurrentScene(std::shared_ptr<Scene> scene);

      /**
       * Initializes the game and all sub managers used by game.
       */
      void init();

      /**
       * Updates the game and all sub managers used by game.
       */
      void update();

      /**
       * Deloads game and all sub managers used by game.
       */
      ~Game();
  };
}